## This package is very useful for implementing data science projects

1. you can use it for dealing with files operations
2. you can load yaml files
3. you can save json data to a file

thanks for Krish Naik's perfect video, this package just for learning purposes.